@@ -2,7 +2,7 @@
 Base package to import top level modules
 """
 from formish.forms import Form
-from formish.validation import FieldError, FormError, FormishError
+from formish.validation import FormError, FormishError, NoActionError
 from formish.widgets import *
 from formish.util import form_in_request
 
