@@ -11,6 +11,9 @@ from formish import validation
 from formish import widgets
 from formish.renderer import _default_renderer
 
+from peak.util.proxies import ObjectWrapper
+
+
 
 class Action(object):
     """
@@ -50,8 +53,10 @@ def _classes(self):
         classes.append('required')
     if self.widget is not None and self.widget.css_class:
         classes.append(self.widget.css_class)
-    if self.error.val:
+    if str(self.error):
         classes.append('error')
+    if getattr(self,'contains_error',None):
+        classes.append('contains-error')
     return ' '.join(classes)
             
 
@@ -89,7 +94,7 @@ class TemplatedString(object):
     def __str__(self):
         if not self.val:
             return ''
-        return self.val
+        return unicode(self.val)
 
     def __call__(self):
         renderer = self.obj.form.renderer
@@ -162,7 +167,7 @@ class Field(object):
     def value(self):
         """Convert the request_data to a value object for the form or None."""
         if '*' in self.name:
-            return ['']
+            return  self.widget.pre_render(self.attr, None)
         return self.form.request_data.get(self.name, None)
 
 
@@ -220,18 +225,14 @@ class Field(object):
         return fall_back_renderer(renderer, name, widget, vars)
 
 
-class CollectionFieldsWrapper(object):
+class CollectionFieldsWrapper(ObjectWrapper):
     """
     Allow fields attr of a form to be accessed (as a generator) but also callable
     """
+    collection = None
     def __init__(self, collection):
+        ObjectWrapper.__init__(self, iter(collection.collection_fields()))
         self.collection = collection
-        self.val= collection.collection_fields()
-
-    def __iter__(self):
-        if self.val is None:
-            return iter([])
-        return iter(self.val)
 
     def __call__(self):
         renderer = self.collection.form.renderer
@@ -314,6 +315,13 @@ class Collection(object):
         val = self.form.errors.get(self.name, None)
         return TemplatedString(self, 'error', val)
 
+    @property
+    def contains_error(self):
+        """ Check to see if any child elements have errors """
+        for k in self.form.errors.keys():
+            if k.startswith(self.name):
+                return True
+        return False
 
     @property
     def widget(self):
@@ -509,18 +517,14 @@ class BoundWidget(object):
             attrname = attrclassstr[8:-2]
         return '<bound widget name="%s", widget="%s", type="%s">'%(self.field.name, self.widget._template, attrname)
 
-class FormFieldsWrapper(object):
+class FormFieldsWrapper(ObjectWrapper):
     """
     Allow fields attr of a form to be accessed (as a generator) but also callable
     """
+    form = None
     def __init__(self, form):
         self.form = form
-        self.val= form.structure.fields
-
-    def __iter__(self):
-        if self.val is None:
-            return iter([])
-        return iter(self.val)
+        ObjectWrapper.__init__(self, form.structure.fields)
 
     def __call__(self):
         return self.form.renderer('/formish/form_fields.html', {'form':self.form})
@@ -746,7 +750,7 @@ class Form(object):
             self.structure.attr.validate(data)
         except schemaish.attr.Invalid, e:
             for key, value in e.error_dict.items():
-                if not self.errors.has_key(key):
+                if key not in self.errors:
                     self.errors[key] = value
         if len(self.errors.keys()) > 0:
             err_msg = 'Tried to access data but conversion' \
