@@ -1,6 +1,7 @@
 import logging, os.path
 import formish, schemaish, validatish
 from formish.filehandler import TempFileHandlerWeb
+from testish.lib import xformish
 
 log = logging.getLogger(__name__)
 
@@ -22,7 +23,7 @@ def String():
     form = formish.Form(schema, 'form')
     return form
 
-def functest_String(self, sel):
+def functest_String(self, sel):#{{{
     sel.open("/String")
 
     sel.click("form-action-submit")
@@ -42,9 +43,9 @@ def functest_String(self, sel):
     try: self.failUnless(sel.is_text_present("{'myStringField': u'80'}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
-def unittest_String(self):
+def unittest_String(self):#{{{
     # Test no data
     f = String()
     self.assertIdHasValue(f, 'form-myStringField', '')
@@ -59,7 +60,7 @@ def unittest_String(self):
     testdata = {'myStringField': '8'}
     f.defaults = testdata
     self.assertIdHasValue(f, 'form-myStringField', '8')
-    self.assertRoundTrip(f, testdata)
+    self.assertRoundTrip(f, testdata)#}}}
 
 
 def Integer():
@@ -71,7 +72,7 @@ def Integer():
     form = formish.Form(schema, 'form')
     return form
 
-def functest_Integer(self,sel):
+def functest_Integer(self,sel):#{{{
     sel.open("/Integer")
 
     sel.click("form-action-submit")
@@ -97,9 +98,9 @@ def functest_Integer(self,sel):
     try: self.failUnless(sel.is_text_present("{'myIntegerField': 8}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
-def unittest_Integer(self):
+def unittest_Integer(self):#{{{
     # Test no data
     f = Integer()
     self.assertIdHasValue(f, 'form-myIntegerField', '')
@@ -114,7 +115,7 @@ def unittest_Integer(self):
     testdata = {'myIntegerField': 8}
     f.defaults = testdata
     self.assertIdHasValue(f, 'form-myIntegerField', '8')
-    self.assertRoundTrip(f, testdata)
+    self.assertRoundTrip(f, testdata)#}}}
 
 def Date():
     """
@@ -125,7 +126,7 @@ def Date():
     form = formish.Form(schema, 'form')
     return form
 
-def functest_Date(self, sel):
+def functest_Date(self, sel):#{{{
 
     sel.open("/Date")
 
@@ -152,7 +153,7 @@ def functest_Date(self, sel):
     try: self.failUnless(sel.is_text_present("{'myDateField': datetime.date(2008, 12, 18)}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
 def Float():
     """
@@ -163,7 +164,7 @@ def Float():
     form = formish.Form(schema, 'form')
     return form
 
-def functest_Float(self, sel):
+def functest_Float(self, sel):#{{{
     sel.open("/Float")
 
     sel.click("form-action-submit")
@@ -189,7 +190,7 @@ def functest_Float(self, sel):
     try: self.failUnless(sel.is_text_present("{'myFloatField': 12.27}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
 
 
@@ -202,7 +203,7 @@ def Boolean():
     form = formish.Form(schema, 'form')
     return form
 
-def functest_Boolean(self, sel):
+def functest_Boolean(self, sel):#{{{
     sel.open("/Boolean")
 
     sel.click("form-action-submit")
@@ -234,7 +235,7 @@ def functest_Boolean(self, sel):
     try: self.failUnless(sel.is_text_present("{'myBooleanField': False}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
 
 def Decimal():
@@ -247,7 +248,7 @@ def Decimal():
     return form
 
 
-def functest_Decimal(self, sel):
+def functest_Decimal(self, sel):#{{{
     sel.open("/Decimal")
 
     sel.click("form-action-submit")
@@ -273,7 +274,7 @@ def functest_Decimal(self, sel):
     try: self.failUnless(sel.is_text_present("{'myDecimalField': Decimal(\"18.001\")}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
 def RequiredStringAndCheckbox():
     """
@@ -286,7 +287,7 @@ def RequiredStringAndCheckbox():
     form['myBoolean'].widget=formish.Checkbox()
     return form
 
-def functest_RequiredStringAndCheckbox(self, sel):
+def functest_RequiredStringAndCheckbox(self, sel):#{{{
     sel.open("/RequiredStringAndCheckbox")
 
     sel.click("form-action-submit")
@@ -307,7 +308,7 @@ def functest_RequiredStringAndCheckbox(self, sel):
     try: self.failUnless(sel.is_text_present("{'myBoolean': True, 'myString': u'anythingelse'}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
 def File():
     """
@@ -319,7 +320,7 @@ def File():
     form['myFileField'].widget = formish.FileUpload(filehandler=TempFileHandlerWeb())
     return form
 
-def functest_File(self, sel):
+def functest_File(self, sel):#{{{
     sel.open("/File")
 
     sel.click("form-action-submit")
@@ -335,7 +336,7 @@ def functest_File(self, sel):
     try: self.failUnless(sel.is_text_present("{'myFileField': <schemaish.type.File object at"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
 #########################
 #
@@ -476,6 +477,36 @@ def MinLengthCheckboxMultiChoice():
     form['multiChoice'].widget = formish.CheckboxMultiChoice(options)
     return form
 
+def MinRange():
+    """
+    Minimum Value fields - this one is min value of 4
+    """
+    schema = schemaish.Structure()
+    schema.add('min', schemaish.Float(validator=validatish.Range(min=4)))
+
+    form = formish.Form(schema, 'form')
+    return form
+
+def MaxRange():
+    """
+    Maximum value for a field - this one is max of 8
+    """
+    schema = schemaish.Structure()
+    schema.add('max', schemaish.Float(validator=validatish.Range(max=8)))
+
+    form = formish.Form(schema, 'form')
+    return form
+
+def MinMaxRange():
+    """
+    Minimum and maximum value
+    """
+    schema = schemaish.Structure()
+    schema.add('minmax', schemaish.Float(validator=validatish.Range(min=4,max=8)))
+
+    form = formish.Form(schema, 'form')
+    return form
+
 def PlainText():
     """
     Plain Text (alphanum only)
@@ -507,6 +538,22 @@ def All():
     form = formish.Form(schema, 'form')
     return form
 
+
+def ValidationOnSequenceItem():
+    """
+    A structure witin a sequence, should be enhanced with javascript
+    """
+    substructure = schemaish.Structure()
+    substructure.add( 'a', schemaish.String(validator=validatish.Required()) )
+    substructure.add( 'b', schemaish.Integer() )
+
+    schema = schemaish.Structure()
+    schema.add( 'myList', schemaish.Sequence( substructure ))
+
+    form = formish.Form(schema, 'form')
+    return form
+
+
 ########################
 #
 #   Checkbox
@@ -711,7 +758,7 @@ def SequenceOfUploadStructures():
     form['myList.*.a'].widget = formish.FileUpload(filehandler=TempFileHandlerWeb())
     return form
 
-def functest_SequenceOfUploadStructures(self, sel):
+def functest_SequenceOfUploadStructures(self, sel):#{{{
 
     sel.open("/SequenceOfUploadStructures")
     sel.wait_for_page_to_load("30000")
@@ -725,7 +772,7 @@ def functest_SequenceOfUploadStructures(self, sel):
     try: self.failUnless(sel.is_text_present("{'myList': [{'a': <schemaish.type.File object at *, 'b': 13}]}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
 def SequenceOfStructuresWithSelects():
     """
@@ -746,7 +793,7 @@ def SequenceOfStructuresWithSelects():
     form.defaults = {'myList': [{'a':'foo','b':'b'}]}
     return form
 
-def functest_SequenceOfStructuresWithSelects(self, sel):
+def functest_SequenceOfStructuresWithSelects(self, sel):#{{{
     sel.open("/SequenceOfStructuresWithSelects")
 
     try: self.assertEqual("foo", sel.get_value("form-myList-0-a"))
@@ -762,8 +809,51 @@ def functest_SequenceOfStructuresWithSelects(self, sel):
     try: self.assertEqual("", sel.get_value("form-myList-1-b"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    return
+    return#}}}
 
+def SequenceOfDateParts():
+    """
+    A test of a sequence of more complicated structures
+    """
+    schema = schemaish.Structure()
+    schema.add('birthdays',
+    schemaish.Sequence(
+        schemaish.Structure(
+           [ ('date', schemaish.Date(validator=validatish.Required())), ]
+           ))) 
+    form = formish.Form(schema, 'form')
+    form['birthdays.*.date'].widget = formish.DateParts()
+    return form
+
+def functest_SequenceOfDateParts(self, sel):#{{{
+    sel.open("/SequenceOfDateParts")
+
+    sel.click_at("css=#form-birthdays-field > a", "")
+    try: self.assertEqual("", sel.get_value("form-birthdays-0-date"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+    return#}}}
+
+
+def SequenceOfStructures():
+    """
+    A test of a sequence of more complicated structures
+    """
+    schema = schemaish.Structure()
+    schema.add('employment', schemaish.Sequence(schemaish.Structure([
+        ('job_title', schemaish.String(validator=validatish.Required())),
+        ('joined', schemaish.String(validator=validatish.Required())),
+        ('left', schemaish.String(validator=validatish.Required())),
+        ('time_spent', schemaish.String(validator=validatish.Required())),
+        ('num_employees', schemaish.String(validator=validatish.Required())),
+        ('comments', schemaish.String(validator=validatish.Required())),
+        ('primary', schemaish.Boolean())])))
+
+    form = formish.Form(schema, 'form')
+    form['employment.*.primary'].widget=formish.Checkbox()
+    form['employment.*.joined'].widget = xformish.ApproximateDateParts()
+    form['employment.*.left'].widget = xformish.ApproximateDateParts()
+    return form
 
 
 def GranularFormLayout():
@@ -905,4 +995,4 @@ ${form.footer()|n}
 
     """
 
-    
+# vim: fdm=marker:foldclose=all
