@@ -89,39 +89,6 @@ def getNestedProperty(data, dottedkey):
     except (KeyError, IndexError):
         return None
 
-def validate(structure, request_data, errors=None, keyprefix=None):
-    """
-    Take a schemaish structure and use it's validators to return any errors
-    
-    :arg structure: schemaish structure
-    :arg request_data: webob request
-    :arg errors: we can pass in an errors dictionary and any failures will get stored on it (internal - used while recursing)
-    :arg keyprefix: used when recursively validating a structure (internal - used while recursing)
-    """
-    if errors is None:
-        errors = dottedDict()
-    # Validate each field in the schema, return 
-    # a dictionary of errors keyed by field name
-    for attr in structure.attrs:
-        # function is recursive so we have to build up a full key
-        if keyprefix is None:
-            newprefix = attr[0]
-        else:
-            newprefix = '%s.%s'% (keyprefix, attr[0])
-        try:
-            if hasattr(attr[1],'attrs'):
-                # recurse
-                validate(attr[1], request_data,
-                         errors=errors, keyprefix=newprefix)
-            else: 
-                # we only validate data that exists
-                if request_data.has_key(newprefix):
-                    # firstly convert sequences
-                    data = convert_sequences(request_data[newprefix])
-                    attr[1].validate(data)
-        except (Invalid, FieldValidationError), e:
-            errors[newprefix] = e
-    return errors
 
 def convert_data_to_request_data(form_structure, data,
                       request_data=None, errors=None):
@@ -191,7 +158,7 @@ def convert_request_data_to_data(form_structure,
                 data[field.name] = field.widget.convert(field.attr, \
                                                 request_data.get(field.name,[]))
         except convert.ConvertError, e:
-            errors[field.name] = e
+            errors[field.name] = e.message
     
     data = recursive_convert_sequences(dottedDict(data))
     return data
@@ -248,29 +215,4 @@ class NoActionError(FormishError):
     signal that the form (not an individual field) failed to validate.
     """
     pass
-    
-    
-class FieldError(FormishError):
-    """
-    Base class for field-related exceptions. The failure message and the failing
-    field name are stored as attributes.
-    """
-    def __init__(self, message, field_name=None):
-        FormishError.__init__(self, message, field_name)
-        self.field_name = field_name
-
-
-class FieldValidationError(FieldError):
-    """
-    Exception that signals that a field failed to validate.
-    """
-    pass
-    
-    
-class FieldRequiredError(FieldValidationError):
-    """
-    Exception that signals that a field that is marked as required was not
-    entered.
-    """
-    pass
 
